@@ -4,8 +4,8 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef OPTIONSMODEL_H
-#define OPTIONSMODEL_H
+#ifndef OPTIONS_MODEL_H
+#define OPTIONS_MODEL_H
 
 #include <QObject>
 #include <QList>
@@ -23,8 +23,6 @@ class OptionsModel : public QAbstractListModel
 
     Q_PROPERTY(int rowCount READ rowCount NOTIFY rowCountChanged)
 
-    Q_PROPERTY(bool isModified READ isModified NOTIFY isModifiedChanged)
-
 public:
     enum OptionsModelRoles {
         NameRole = Qt::UserRole + 1,
@@ -37,7 +35,8 @@ public:
         ValueListRole,
         UnitRole,
         TypeRole,
-        VisibleRole,
+        StateRole,
+        QuickAccessRole
     };
 
     explicit OptionsModel(QObject *parent = nullptr);
@@ -54,23 +53,15 @@ public:
 
     void setOptionsList(const QList<KSaneIface::KSaneOption *> optionsList);
 
-    bool isModified() const;
-
-    Q_INVOKABLE void resetOptionsValues();
-
-    Q_INVOKABLE void saveOptionsValues();
-
     void clearOptions();
 
 Q_SIGNALS:
 
     void rowCountChanged();
 
-    void isModifiedChanged();
-
 private:
 
     std::unique_ptr<OptionsModelPrivate> d;
 };
 
-#endif // OPTIONSMODEL_H
+#endif // OPTIONS_MODEL_H
